==> oauth2-sdk-authentication-3.2.1.4-sources.jar: cn/herodotus/engine/oauth2/authentication/customizer/OAuth2ErrorCodeMapperBuilderCustomizer.java <==
/*
 * Copyright (c) 2020-2030 郑庚伟 ZHENGGENGWEI (码匠君) (herodotus@aliyun.com & www.herodotus.cn)
 *
 * Dante Engine licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.gnu.org/licenses/lgpl-3.0.html>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cn.herodotus.engine.oauth2.authentication.customizer;

import cn.herodotus.stirrup.kernel.definition.constants.ErrorCodeMapperBuilderOrdered;
import cn.herodotus.stirrup.kernel.definition.function.ErrorCodeMapperBuilderCustomizer;
import cn.herodotus.stirrup.kernel.definition.support.ErrorCodeMapperBuilder;
import cn.herodotus.engine.oauth2.core.constants.OAuth2ErrorCodes;
import org.springframework.core.Ordered;

/**
 * <p>Description: OAuth2 Authentication 模块内置错误代码生成器 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/9/26 22:11
 */
public class OAuth2ErrorCodeMapperBuilderCustomizer implements ErrorCodeMapperBuilderCustomizer, Ordered {
    @Override
    public void customize(ErrorCodeMapperBuilder builder) {
        builder.notAcceptable(
                OAuth2ErrorCodes.USERNAME_ALREADY_EXISTS
        );
    }

    @Override
    public int getOrder() {
        return ErrorCodeMapperBuilderOrdered.OAUTH2;
    }
}

==> oauth2-sdk-authentication-3.2.4.0-sources.jar: cn/herodotus/engine/oauth2/authentication/customizer/OAuth2ErrorCodeMapperBuilderCustomizer.java <==
/*
 * Copyright (c) 2020-2030 郑庚伟 ZHENGGENGWEI (码匠君) (herodotus@aliyun.com & www.herodotus.cn)
 *
 * Dante Engine licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.gnu.org/licenses/lgpl-3.0.html>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cn.herodotus.engine.oauth2.authentication.customizer;

import cn.herodotus.engine.assistant.definition.constants.ErrorCodeMapperBuilderOrdered;
import cn.herodotus.engine.assistant.definition.function.ErrorCodeMapperBuilderCustomizer;
import cn.herodotus.engine.assistant.definition.support.ErrorCodeMapperBuilder;
import cn.herodotus.engine.oauth2.core.constants.OAuth2ErrorCodes;
import org.springframework.core.Ordered;

/**
 * <p>Description: OAuth2 Authentication 模块内置错误代码生成器 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/9/26 22:11
 */
public class OAuth2ErrorCodeMapperBuilderCustomizer implements ErrorCodeMapperBuilderCustomizer, Ordered {
    @Override
    public void customize(ErrorCodeMapperBuilder builder) {
        builder.notAcceptable(
                OAuth2ErrorCodes.USERNAME_ALREADY_EXISTS
        );
    }

    @Override
    public int getOrder() {
        return ErrorCodeMapperBuilderOrdered.OAUTH2;
    }
}
